# CHG-{{ACID}}: {{TITLE}}

**Applies to:** {{PREFIX}} project
**Last updated:** {{DATE}}
**Last reviewed:** {{DATE}}
**Status:** Proposed
**Date:** {{DATE}}
**Requested by:** —
**Priority:** Medium
**Change Type:** Normal

---

## What

<what is being changed>

## Why

<why this change is needed>

## Impact Analysis

- **Systems affected:** <list>
- **Rollback plan:** <how to undo>

## Implementation Plan

1. Step 1

---

## Change History

| Date | Change | By |
|------|--------|----|
| {{DATE}} | Initial version | — |
